
Authors
=======

* Angeline G. Burrell - https://github.com/aburrell
* Christer van der Meeren - https://github.com/cmeeren
* Karl M. Laundal - https://github.com/klaundal
* Hugo van Kemenade - https://github.com/hugovk

Thanks
======

* Marina Shmidt - Testing and code review
* Bill Rideout - Testing
* dinsmoro - Testing - https://github.com/dinsmoro
